#ifndef APPLICATIONINTERFACE_H
#define APPLICATIONINTERFACE_H

#include <QObject>

class MWidget;
class QString;

class ApplicationInterface : public QObject
{
    Q_OBJECT

public:
    /*! \brief Constructor
     * \param parent the parent QObject
     */
    ApplicationInterface(QObject *parent = 0);

    //! \brief Destructor
    virtual ~ApplicationInterface();

    /*! \brief Used to display \a widget in the application using this library
     *  Ownership of \a widget is transferred to ApplicationInterface
     *  \param widget The widget that is displayed
     *  \param title The title for the page
     */
    void showSubPage(MWidget *widget, const QString &title);

    /*! \brief Returns the widget that was set with showSubpage(...)
     *  Ownership of the widget is transferred to the caller
     */
    MWidget *subPageWidget();

    //! \brief Returns the intended title for the page
    const QString &title() const;

    /*! \brief Used to start the media playback in the application
     * \param uriList List of the media Uris to play
     * \param playIndex The starting index for playback
     * \param callerId Optional identification for the caller
     */
    void play(const QStringList &uriList,
              uint playIndex = 0,
              const QString &callerId = QString());

signals:
    //! \brief Signals that a widget has been set and should be shown
    void subPageWidgetChanged();

    /*! \brief Signals that a media needs to be played
     * \param uriList List of the media Uris to play
     * \param playIndex The starting index for playback
     * \param callerId Optional identification for the caller
     */
    void playRequested(const QStringList &uriList,
                       uint playIndex,
                       const QString &callerId);

private:
    //! The widget that is displayed
    MWidget *subPage;

    //! Title for the subpage
    QString subPageTitle;

};

#endif // APPLICATIONINTERFACE_H
