#ifndef MUSICAPPLICATIONACTIONCONTENT_H
#define MUSICAPPLICATIONACTIONCONTENT_H

#include "applicationactioncontent.h"

class MusicExtensionSongData;

#include <QObject>
#include <QVariant>
#include <QHash>

/*!
 * \class MusicApplicationActionContent
 * \brief Describes a single action in Music suite
 */
class MusicApplicationActionContent : public ApplicationActionContent {
    Q_OBJECT

public:
    //! Metadata key for song title
    const QString songKey;

    //! Metadata key for artist
    const QString artistKey;

    //! Metadata key for album
    const QString albumKey;

    //! Metadata key for genre
    const QString genreKey;

    //! Enumerator for action types
    typedef enum ActionContext {
        TrackContext,
        AlbumContext,
        ArtistContext,
        GenreContext } ActionContext;

    /*!
     * \brief Constructor
     * \param parent the parent QObject
     */
    MusicApplicationActionContent(QObject *parent) :
            ApplicationActionContent(parent),
            songKey("song"),
            artistKey("artist"),
            albumKey("album"),
            genreKey("genre")
    {}

    /*!
     * \brief Destructor
     */
    ~MusicApplicationActionContent(){}

    /*!
     * \brief Sets track content
     * \param song Song title
     * \param artist Artist title
     * \param album Album title
     * \param genre Genre
     */
    void setTrackContent(const QString &song, const QString &artist,
                                    const QString &album, const QString &genre)
    {
        context = TrackContext;
        metaData.insert(songKey, song);
        metaData.insert(artistKey, artist);
        metaData.insert(albumKey, album);
        metaData.insert(genreKey, genre);
    }

    /*!
     * \brief Sets album content
     * \param artist Artist title
     * \param album Album title
     */
    void setAlbumContent(const QString &artist, const QString &album)
    {
        context = AlbumContext;
        metaData.insert(artistKey, artist);
        metaData.insert(albumKey, album);
    }

    /*!
     * \brief Sets artist content
     * \param artist Artist title
     */
    void setArtistContent(const QString &artist)
    {
        context = ArtistContext;
        metaData.insert(artistKey, artist);
    }

    /*!
     * \brief Sets genre content
     * \param song Song title
     * \param artist Artist title
     * \param album Album title
     * \param genre Genre
     */
    void setGenreContent(const QString &genre)
    {
        context = GenreContext;
        metaData.insert(genreKey, genre);
    }

    /*!
     * \brief Returns the actions context
     * \return an enumerate value of type ActionContext
     */
    ActionContext getContext() const
    {
        return context;
    }

private:
    ActionContext context;

};

#endif // MUSICAPPLICATIONACTIONCONTENT_H
