#ifndef VIDEOAPPLICATIONACTIONCONTENT_H
#define VIDEOAPPLICATIONACTIONCONTENT_H

#include "applicationactioncontent.h"

#include <QObject>
#include <QVariant>
#include <QHash>

/*!
 * \class VideoApplicationActionContent
 * \brief Describes a single action in video-suite
 */
class VideoApplicationActionContent : public ApplicationActionContent {
    Q_OBJECT

public:
    //! Metadata key for video Uri
    const QString uriKey;

    //! Metadata key for video title
    const QString titleKey;

    //! Metadata key for video series
    const QString seriesKey;

    //! Metadata key for video episode
    const QString episodeKey;

    //! Enumerator for action types
    typedef enum ActionContext
    {
        VideoContext //! Video playback or details viewed
    } ActionContext;

    /*!
     * \brief Constructor
     * \param parent the parent QObject
     */
    VideoApplicationActionContent(QObject *parent) :
            ApplicationActionContent(parent),
            uriKey("uri"),
            titleKey("title"),
            seriesKey("series"),
            episodeKey("episode")
    {
    }

    /*!
     * \brief Destructor
     */
    ~VideoApplicationActionContent()
    {
    }

    /*!
     * \brief Sets the context to VideoContext
     * setVideoContent sets the actions context to VideoContext.
     * It is used to identify a video that is played or viewed in
     * the details page.
     * \param uri Video uri
     * \param title Video title
     * \param series Video series
     * \param episode Video episode
     */
    void setVideoContent(const QString &uri,
                         const QString &title,
                         const QString &series,
                         const QString &episode)
    {
        context = VideoContext;
        metaData.insert(uriKey, uri);
        metaData.insert(titleKey, title);
        metaData.insert(seriesKey, series);
        metaData.insert(episodeKey, episode);
    }

    /*!
     * \brief Returns the actions context
     * \return an enumerate value of type ActionContext
     */
    ActionContext getContext() const
    {
        return context;
    }

private:
    ActionContext context;

};

#endif // VIDEOAPPLICATIONACTIONCONTENT_H
