#ifndef VIDEOEXTENSIONINTERFACES_H
#define VIDEOEXTENSIONINTERFACES_H

#include <QObject>
#include <MApplicationExtensionInterface>


/*!
 * \class VideoPlayerExtensionInterface
 * \brief Defines the extension interface for video players details view extensions.
 *
 * All extensions that want to add their extension widgets to video player details view
 * need to inherit this class and implement the interface
 *
 * \section Example
 * class MyVideoDetailExtension : public AbstractExtensionWidget, public VideoPlayerExtensionInterface {
 * public:
 *    Q_OBJECT
 *    Q_INTERFACES(VideoPlayerExtensionInterface)
 * ...
 * }
 */
class VideoPlayerExtensionInterface
{
public:
    virtual ~VideoPlayerExtensionInterface(){}
};
Q_DECLARE_INTERFACE(VideoPlayerExtensionInterface, "com.nokia.VideoSuite.extensions.PlayerInterface/1.0");

/*!
 * \class VideoPromotionExtensionInterface
 * \brief Defines the extension interface for video player main view extensions.
 *
 * All extensions that want to add their own recommendation set to video player recommendations tab
 * need to inherit this class and implement the interface.
 *
 * \section Example
 * class MyPromotionExtension : public AbstractExtensionWidget, public VideoPromotionExtensionInterface {
 * public:
 *    Q_OBJECT
 *    Q_INTERFACES(VideoPromotionExtensionInterface)
 * ...
 * }
 */
class VideoPromotionExtensionInterface
{
public:
    virtual ~VideoPromotionExtensionInterface(){}
};
Q_DECLARE_INTERFACE(VideoPromotionExtensionInterface, "com.nokia.VideoSuite.extensions.PromotionInterface/1.0");

#endif //VIDEOEXTENSIONINTERFACES_H
